'use strict';

const assert = require(`yeoman-assert`);
const helpers = require(`yeoman-test`);
const mocha = require(`mocha`);

const beforeEach = mocha.beforeEach;
const describe = mocha.describe;
const it = mocha.it;

const PROMPTS = {
  projectName: `test`,
  name: `Full Name`,
  email: `name@example.com`,
  website: `www.example.com`,
  license: `Apache-2.0`,
};

const EXPECTED_FILES = [
  `.gitattributes`,
  `.gitignore`,
  `.pylintrc`,
  `CONTRIBUTING.md`,
  `README.md`,
  `setup.py`,
  `tox.ini`,
];

describe(`python-library:app`, function () {
  describe(`basic`, function () {
    it(`should load via require without crashing`, function () {
      assert(require(__dirname) !== undefined);
    });
  });

  describe(`generating`, function () {
    // Because this test suite runs the actual generator, its runtime is dependent on the underlying file system.
    // If writes are slow then the tests will timeout. Therefore we must arbitrarily increase the default Mocha
    // timeout applied to test cases.
    this.timeout(10000);

    beforeEach(function () {
      this.runGenerator = helpers
        .run(__dirname)
        .withPrompts(PROMPTS);
    });

    it(`creates files`, function (done) {
      this.runGenerator.on(`end`, function () {
        assert.file(EXPECTED_FILES);

        assert.noFile([
          `.travis.yml`,
        ]);

        done();
      });
    });

    it(`creates files without welcome message`, function (done) {
      this.runGenerator.withOptions({'skip-welcome-message': true}).on(`end`, function () {
        assert.file(EXPECTED_FILES);

        assert.noFile([
          `.travis.yml`,
        ]);

        done();
      });
    });

    it(`creates travis CI file`, function (done) {
      this.runGenerator.withPrompts({ciProvider: `Travis CI`}).on(`end`, function () {
        assert.file(EXPECTED_FILES);

        assert.file([
          `.travis.yml`,
        ]);

        done();
      });
    });
  });
});
